==> ejc-probuilddiary-api-3.0.0-20220916.063707-4-sources.jar: com/ejianc/business/probuilddiary/project/vo/ProjectLogMaterialVO.java <==
package com.ejianc.business.probuilddiary.project.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 项目日志-材料进场情况（材料员）
 *
 * @author baipengyan
 */
public class ProjectLogMaterialVO extends BaseVO {
	private static final long serialVersionUID = -4028759655843166519L;

	private Long personId; // 个人日志id
	private String materialMemo; // 工作描述
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private String fileType; // 文件类型


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public String getMaterialMemo() {
		return materialMemo;
	}

	public void setMaterialMemo(String materialMemo) {
		this.materialMemo = materialMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}
}

==> ejc-probuilddiary-api-3.0.0-20220919.091701-11-sources.jar: com/ejianc/business/probuilddiary/project/vo/ProjectLogMaterialVO.java <==
package com.ejianc.business.probuilddiary.project.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 项目日志-材料进场情况（材料员）
 *
 * @author baipengyan
 */
public class ProjectLogMaterialVO extends BaseVO {
	private static final long serialVersionUID = -4028759655843166519L;

	private Long personId; // 个人日志id
	private String materialMemo; // 工作描述
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private String fileType; // 文件类型
	private Boolean updateFlag; // 更新状态


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public String getMaterialMemo() {
		return materialMemo;
	}

	public void setMaterialMemo(String materialMemo) {
		this.materialMemo = materialMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public Boolean getUpdateFlag() {
		return updateFlag;
	}

	public void setUpdateFlag(Boolean updateFlag) {
		this.updateFlag = updateFlag;
	}
}
